@@ -1,52 +1,39 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sieveeditormainwindow.h"
 
-#include "sieveeditormainwidget.h"
-#include "sieveeditorconfiguredialog.h"
-#include "serversievesettingsdialog.h"
-#include "sieveserversettings.h"
-#include "sieveeditorcentralwidget.h"
-#include "sieveeditorglobalconfig.h"
-#include "sievepurposemenuwidget.h"
-#include "sieveeditorbookmarks.h"
 #include "importwizard/importimapsettingwizard.h"
+#include "serversievesettingsdialog.h"
+#include "sieveeditorbookmarks.h"
+#include "sieveeditorcentralwidget.h"
+#include "sieveeditorconfiguredialog.h"
+#include "sieveeditorglobalconfig.h"
+#include "sieveeditormainwidget.h"
+#include "sievepurposemenuwidget.h"
+#include "sieveserversettings.h"
 #include <PimCommon/KActionMenuChangeCase>
 
-#include <KSharedConfig>
 #include <KIconEngine>
 #include <KIconLoader>
+#include <KSharedConfig>
 #include <PimCommon/NetworkManager>
 
-#include <KLocalizedString>
-#include <KConfigGroup>
-#include <KStandardAction>
 #include <KActionCollection>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KStandardAction>
 #include <QAction>
-#include <QStatusBar>
 #include <QIcon>
+#include <QStatusBar>
 
-#include <QPointer>
-#include <QLabel>
 #include <QCloseEvent>
+#include <QLabel>
 #include <QNetworkConfigurationManager>
+#include <QPointer>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -58,7 +45,7 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
 {
     mMainWidget = new SieveEditorCentralWidget(this, actionCollection());
 #ifdef WITH_KUSERFEEDBACK
-    //Initialize
+    // Initialize
     (void)UserFeedBackManager::self();
 #endif
     connect(mMainWidget, &SieveEditorCentralWidget::configureClicked, this, &SieveEditorMainWindow::slotConfigure);
@@ -69,8 +56,10 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
     setupGUI();
     readConfig();
     initStatusBar();
-    connect(PimCommon::NetworkManager::self()->networkConfigureManager(), &QNetworkConfigurationManager::onlineStateChanged,
-            this, &SieveEditorMainWindow::slotSystemNetworkOnlineStateChanged);
+    connect(PimCommon::NetworkManager::self()->networkConfigureManager(),
+            &QNetworkConfigurationManager::onlineStateChanged,
+            this,
+            &SieveEditorMainWindow::slotSystemNetworkOnlineStateChanged);
 
     connect(mMainWidget->sieveEditorMainWidget()->tabWidget(), &QTabWidget::currentChanged, this, &SieveEditorMainWindow::slotUpdateActions);
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::modeEditorChanged, this, &SieveEditorMainWindow::slotUpdateActions);
@@ -81,7 +70,7 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::sieveEditorTabCurrentChanged, this, &SieveEditorMainWindow::slotUpdateActions);
     mMainWidget->sieveEditorMainWidget()->refreshList();
 #ifdef WITH_KUSERFEEDBACK
-    auto *userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
+    auto userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
     userFeedBackNotificationPopup->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
 #endif
 }
@@ -91,9 +80,6 @@ SieveEditorMainWindow::~SieveEditorMainWindow()
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group = config->group(QStringLiteral("SieveEditorMainWindow"));
     group.writeEntry("Size", size());
-    if (SieveEditorGlobalConfig::self()->closeWallet()) {
-        SieveServerSettings::self()->closeWallet();
-    }
 }
 
 void SieveEditorMainWindow::initStatusBar()
@@ -156,7 +142,7 @@ void SieveEditorMainWindow::setupActions()
     mNewScript = new QAction(i18n("Create New Script..."), this);
     connect(mNewScript, &QAction::triggered, this, &SieveEditorMainWindow::slotCreateNewScript);
     ac->addAction(QStringLiteral("create_new_script"), mNewScript);
-    ac->setDefaultShortcut(mNewScript, QKeySequence(Qt::CTRL + Qt::Key_N));
+    ac->setDefaultShortcut(mNewScript, QKeySequence(Qt::CTRL | Qt::Key_N));
     mNewScript->setEnabled(false);
 
     mEditScript = new QAction(i18n("Edit Script..."), this);
@@ -178,7 +164,7 @@ void SieveEditorMainWindow::setupActions()
     mGoToLine = new QAction(i18n("Go to Line..."), this);
     connect(mGoToLine, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotGoToLine);
     mGoToLine->setIcon(QIcon::fromTheme(QStringLiteral("go-jump")));
-    ac->setDefaultShortcut(mGoToLine, QKeySequence(Qt::CTRL + Qt::Key_G));
+    ac->setDefaultShortcut(mGoToLine, QKeySequence(Qt::CTRL | Qt::Key_G));
     ac->addAction(QStringLiteral("gotoline"), mGoToLine);
     mGoToLine->setEnabled(false);
 
@@ -197,7 +183,7 @@ void SieveEditorMainWindow::setupActions()
     ac->addAction(QStringLiteral("import_script"), mImportAction);
     mImportAction->setEnabled(false);
 
-    auto *purposeMenu = new SievePurposeMenuWidget(this, this);
+    auto purposeMenu = new SievePurposeMenuWidget(this, this);
     mShareAction = new QAction(i18n("Share..."), this);
     ac->addAction(QStringLiteral("share_script"), mShareAction);
     mShareAction->setMenu(purposeMenu->menu());
@@ -230,12 +216,12 @@ void SieveEditorMainWindow::setupActions()
     mCommentAction = new QAction(i18n("Comment"), this);
     connect(mCommentAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotComment);
     ac->addAction(QStringLiteral("comment_code"), mCommentAction);
-    ac->setDefaultShortcut(mCommentAction, Qt::CTRL + Qt::Key_D);
+    ac->setDefaultShortcut(mCommentAction, Qt::CTRL | Qt::Key_D);
 
     mUncommentAction = new QAction(i18n("Uncomment"), this);
     connect(mUncommentAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotUncomment);
     ac->addAction(QStringLiteral("uncomment_code"), mUncommentAction);
-    ac->setDefaultShortcut(mUncommentAction, Qt::CTRL + Qt::SHIFT + Qt::Key_D);
+    ac->setDefaultShortcut(mUncommentAction, Qt::CTRL | Qt::SHIFT | Qt::Key_D);
 
     mZoomInAction = KStandardAction::zoomIn(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotZoomIn, this);
     ac->addAction(QStringLiteral("zoom_in"), mZoomInAction);
@@ -251,8 +237,14 @@ void SieveEditorMainWindow::setupActions()
     mMenuChangeCaseAction->appendInActionCollection(ac);
     connect(mMenuChangeCaseAction, &PimCommon::KActionMenuChangeCase::upperCase, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotUpperCase);
     connect(mMenuChangeCaseAction, &PimCommon::KActionMenuChangeCase::lowerCase, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotLowerCase);
-    connect(mMenuChangeCaseAction, &PimCommon::KActionMenuChangeCase::sentenceCase, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotSentenceCase);
-    connect(mMenuChangeCaseAction, &PimCommon::KActionMenuChangeCase::reverseCase, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotReverseCase);
+    connect(mMenuChangeCaseAction,
+            &PimCommon::KActionMenuChangeCase::sentenceCase,
+            mMainWidget->sieveEditorMainWidget(),
+            &SieveEditorMainWidget::slotSentenceCase);
+    connect(mMenuChangeCaseAction,
+            &PimCommon::KActionMenuChangeCase::reverseCase,
+            mMainWidget->sieveEditorMainWidget(),
+            &SieveEditorMainWidget::slotReverseCase);
 
     mBookmarkMenu = new KActionMenu(i18nc("@title:menu", "&Bookmarks"), ac);
     mSieveEditorBookmarks = new SieveEditorBookmarks(this, ac, mBookmarkMenu->menu(), this);
@@ -262,7 +254,7 @@ void SieveEditorMainWindow::setupActions()
     mDebugSieveScriptAction = new QAction(i18n("Debug Sieve Script..."), this);
     connect(mDebugSieveScriptAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotDebugSieveScript);
     ac->addAction(QStringLiteral("debug_sieve"), mDebugSieveScriptAction);
-    ac->setDefaultShortcut(mDebugSieveScriptAction, QKeySequence(Qt::SHIFT + Qt::ALT + Qt::Key_D));
+    ac->setDefaultShortcut(mDebugSieveScriptAction, QKeySequence(Qt::SHIFT | Qt::ALT | Qt::Key_D));
 
     mWrapTextAction = new QAction(i18n("Wordwrap"), this);
     mWrapTextAction->setCheckable(true);
