@@ -1,39 +1,26 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SIEVEEDITORSCRIPTMANAGERWIDGET_H
-#define SIEVEEDITORSCRIPTMANAGERWIDGET_H
+#pragma once
 
-#include <QWidget>
-#include <QUrl>
 #include <KSieveUi/ManageSieveWidget>
+#include <QUrl>
+#include <QWidget>
 
 class SieveEditorManageSieveWidget;
 class QTreeWidgetItem;
-namespace KSieveUi {
+namespace KSieveUi
+{
 }
 class SieveEditorScriptManagerWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SieveEditorScriptManagerWidget(QWidget *parent = nullptr);
-    ~SieveEditorScriptManagerWidget();
+    ~SieveEditorScriptManagerWidget() override;
 
     void updateServerList();
     void editScript();
@@ -61,4 +48,3 @@ private:
     SieveEditorManageSieveWidget *mTreeView = nullptr;
 };
 
-#endif // SIEVEEDITORSCRIPTMANAGERWIDGET_H
